==> limesuite-18.10.0-2-aarch64.pkg.tar.xz: usr/share/doc/limesuite/group___f_n___h_i_g_h___l_v_l.js <==
var group___f_n___h_i_g_h___l_v_l =
[
    [ "Advanced control functions", "group___f_n___a_d_v_a_n_c_e_d.html", "group___f_n___a_d_v_a_n_c_e_d" ],
    [ "lms_range_t", "structlms__range__t.html", [
      [ "max", "structlms__range__t.html#adac6eb2ae170f37534880713b69b48a3", null ],
      [ "min", "structlms__range__t.html#aa52076d1729e3e21118e9dcc14f6dd1a", null ],
      [ "step", "structlms__range__t.html#a5292f11500e4660b2c91220a17c77838", null ]
    ] ],
    [ "lms_name_t", "group___f_n___h_i_g_h___l_v_l.html#ga6af7301710d83c00a6904f14ed1e4a7d", [
      [ "LMS_PATH_NONE", "group___f_n___h_i_g_h___l_v_l.html#gga06fc87d81c62e9abb8790b6e5713c55ba74c125bdf63746671d349471d225b790", null ],
      [ "LMS_PATH_LNAH", "group___f_n___h_i_g_h___l_v_l.html#gga06fc87d81c62e9abb8790b6e5713c55baa0e961e01157f632de19f412b0e07a24", null ],
      [ "LMS_PATH_LNAL", "group___f_n___h_i_g_h___l_v_l.html#gga06fc87d81c62e9abb8790b6e5713c55bafe6fc28e9a3369b0d6eaf4394652b093", null ],
      [ "LMS_PATH_LNAW", "group___f_n___h_i_g_h___l_v_l.html#gga06fc87d81c62e9abb8790b6e5713c55ba7d607965a7814a3a034aa5383366305c", null ],
      [ "LMS_PATH_TX1", "group___f_n___h_i_g_h___l_v_l.html#gga06fc87d81c62e9abb8790b6e5713c55ba09c729f870c9bd9d1c2d31737d66bace", null ],
      [ "LMS_PATH_TX2", "group___f_n___h_i_g_h___l_v_l.html#gga06fc87d81c62e9abb8790b6e5713c55ba7500669da568c873058c5c53712f1d21", null ]
    ] ],
    [ "lms_testsig_t", "group___f_n___h_i_g_h___l_v_l.html#gaf9ea395b6b3cc7bdfb7179cfbf371302", [
      [ "LMS_TESTSIG_NONE", "group___f_n___h_i_g_h___l_v_l.html#ggaf9ea395b6b3cc7bdfb7179cfbf371302a84c8c25fb38420690e2bf6e3d7fa4678", null ],
      [ "LMS_TESTSIG_NCODIV8", "group___f_n___h_i_g_h___l_v_l.html#ggaf9ea395b6b3cc7bdfb7179cfbf371302a512f5eb1fb942907d1d2f9dd0cb57b95", null ],
      [ "LMS_TESTSIG_NCODIV4", "group___f_n___h_i_g_h___l_v_l.html#ggaf9ea395b6b3cc7bdfb7179cfbf371302a9cd4da11ebb85792a750280b78aeb2db", null ],
      [ "LMS_TESTSIG_NCODIV8F", "group___f_n___h_i_g_h___l_v_l.html#ggaf9ea395b6b3cc7bdfb7179cfbf371302af0b9272770073e56657f0e33d70eddf1", null ],
      [ "LMS_TESTSIG_NCODIV4F", "group___f_n___h_i_g_h___l_v_l.html#ggaf9ea395b6b3cc7bdfb7179cfbf371302ae0c1d4593864cdb15bc175e0a69feba6", null ],
      [ "LMS_TESTSIG_DC", "group___f_n___h_i_g_h___l_v_l.html#ggaf9ea395b6b3cc7bdfb7179cfbf371302a2103fbb9adec3c65000a7eb280ecae9e", null ]
    ] ],
    [ "LMS_Calibrate", "group___f_n___h_i_g_h___l_v_l.html#ga30253e6e7221c70d726b6bb06c69e43e", null ],
    [ "LMS_EnableChannel", "group___f_n___h_i_g_h___l_v_l.html#ga221f83ab83d4423b6b810551d261731f", null ],
    [ "LMS_GetAntenna", "group___f_n___h_i_g_h___l_v_l.html#ga77cf01129289aaa3df1b11ddb430d76e", null ],
    [ "LMS_GetAntennaBW", "group___f_n___h_i_g_h___l_v_l.html#gaf940f9c5448e32464453f0051f484e76", null ],
    [ "LMS_GetAntennaList", "group___f_n___h_i_g_h___l_v_l.html#ga7845dcd023f2ee17b38cec55eaff5d9f", null ],
    [ "LMS_GetChipTemperature", "group___f_n___h_i_g_h___l_v_l.html#gac1c5a04e011a57401b5f58806a5bf399", null ],
    [ "LMS_GetGaindB", "group___f_n___h_i_g_h___l_v_l.html#ga234cd6b4e32973d627ae369c353bbd56", null ],
    [ "LMS_GetLOFrequency", "group___f_n___h_i_g_h___l_v_l.html#ga0abde7a7cb9049f96c3d33de71eabd2a", null ],
    [ "LMS_GetLOFrequencyRange", "group___f_n___h_i_g_h___l_v_l.html#ga4fb02282949f45ec15baddc0c591c325", null ],
    [ "LMS_GetLPFBW", "group___f_n___h_i_g_h___l_v_l.html#ga07244b37a3f21bf20f626eddc9b3d399", null ],
    [ "LMS_GetLPFBWRange", "group___f_n___h_i_g_h___l_v_l.html#gaa1ef3ea17a29cb1b087d4bcfbf481169", null ],
    [ "LMS_GetNormalizedGain", "group___f_n___h_i_g_h___l_v_l.html#ga8f560ebdc5a13f2337926acbe13a4120", null ],
    [ "LMS_GetNumChannels", "group___f_n___h_i_g_h___l_v_l.html#gaff8fc19d9453348757cdb2fabb9f7cfd", null ],
    [ "LMS_GetSampleRate", "group___f_n___h_i_g_h___l_v_l.html#ga558a76ff122d71bfe6af57262ea8ed0f", null ],
    [ "LMS_GetSampleRateRange", "group___f_n___h_i_g_h___l_v_l.html#ga2be0ab821f7a13e137c807521bb0e467", null ],
    [ "LMS_GetTestSignal", "group___f_n___h_i_g_h___l_v_l.html#ga0555e1812314d548c15e6cbddcc06612", null ],
    [ "LMS_Init", "group___f_n___h_i_g_h___l_v_l.html#ga804769c6df1bb5c86829f6211c0c56aa", null ],
    [ "LMS_LoadConfig", "group___f_n___h_i_g_h___l_v_l.html#ga6ed2978c8a23248e27406725a293a3c3", null ],
    [ "LMS_SaveConfig", "group___f_n___h_i_g_h___l_v_l.html#ga2160d093e5c947adbaddafec1e041427", null ],
    [ "LMS_SetAntenna", "group___f_n___h_i_g_h___l_v_l.html#gace44b0474b90b6e1cc540ebef650b5d2", null ],
    [ "LMS_SetGaindB", "group___f_n___h_i_g_h___l_v_l.html#ga19d4810a0cf125cf82420f5c6bfcee6f", null ],
    [ "LMS_SetGFIRLPF", "group___f_n___h_i_g_h___l_v_l.html#gabf1f79d0561a8242ffe356d497f5f970", null ],
    [ "LMS_SetLOFrequency", "group___f_n___h_i_g_h___l_v_l.html#ga2c59e97985e0dfccf935c8bd78d5248d", null ],
    [ "LMS_SetLPF", "group___f_n___h_i_g_h___l_v_l.html#gab3696f37529eee3be9c57a37e8c05a4a", null ],
    [ "LMS_SetLPFBW", "group___f_n___h_i_g_h___l_v_l.html#gad7c91857ba6e83bf060e5359420925a7", null ],
    [ "LMS_SetNormalizedGain", "group___f_n___h_i_g_h___l_v_l.html#gad56e10da5335c7c8f74e31dd85d1e288", null ],
    [ "LMS_SetSampleRate", "group___f_n___h_i_g_h___l_v_l.html#ga545f1221449b14be75f3f7855af13dfa", null ],
    [ "LMS_SetTestSignal", "group___f_n___h_i_g_h___l_v_l.html#gac9e743da5a20e2b337238e94644b2c1a", null ],
    [ "LMS_CH_RX", "group___f_n___h_i_g_h___l_v_l.html#ga6315347ecc9dbff0d1ead974be3e8885", null ],
    [ "LMS_CH_TX", "group___f_n___h_i_g_h___l_v_l.html#ga8b66470dd0604888079174a9f9a96daa", null ]
];

==> limesuite-23.11.0-9-aarch64.pkg.tar.xz: usr/share/doc/limesuite/group___f_n___h_i_g_h___l_v_l.js <==
var group___f_n___h_i_g_h___l_v_l =
[
    [ "Advanced control functions", "group___f_n___a_d_v_a_n_c_e_d.html", "group___f_n___a_d_v_a_n_c_e_d" ],
    [ "lms_range_t", "structlms__range__t.html", [
      [ "max", "structlms__range__t.html#adac6eb2ae170f37534880713b69b48a3", null ],
      [ "min", "structlms__range__t.html#aa52076d1729e3e21118e9dcc14f6dd1a", null ],
      [ "step", "structlms__range__t.html#a5292f11500e4660b2c91220a17c77838", null ]
    ] ],
    [ "lms_name_t", "group___f_n___h_i_g_h___l_v_l.html#ga6af7301710d83c00a6904f14ed1e4a7d", [
      [ "LMS_PATH_NONE", "group___f_n___h_i_g_h___l_v_l.html#ggadb1d18269e7c4ddfba0b8c7d046ef0d9a74c125bdf63746671d349471d225b790", null ],
      [ "LMS_PATH_LNAH", "group___f_n___h_i_g_h___l_v_l.html#ggadb1d18269e7c4ddfba0b8c7d046ef0d9aa0e961e01157f632de19f412b0e07a24", null ],
      [ "LMS_PATH_LNAL", "group___f_n___h_i_g_h___l_v_l.html#ggadb1d18269e7c4ddfba0b8c7d046ef0d9afe6fc28e9a3369b0d6eaf4394652b093", null ],
      [ "LMS_PATH_LNAW", "group___f_n___h_i_g_h___l_v_l.html#ggadb1d18269e7c4ddfba0b8c7d046ef0d9a7d607965a7814a3a034aa5383366305c", null ],
      [ "LMS_PATH_TX1", "group___f_n___h_i_g_h___l_v_l.html#ggadb1d18269e7c4ddfba0b8c7d046ef0d9a09c729f870c9bd9d1c2d31737d66bace", null ],
      [ "LMS_PATH_TX2", "group___f_n___h_i_g_h___l_v_l.html#ggadb1d18269e7c4ddfba0b8c7d046ef0d9a7500669da568c873058c5c53712f1d21", null ],
      [ "LMS_PATH_AUTO", "group___f_n___h_i_g_h___l_v_l.html#ggadb1d18269e7c4ddfba0b8c7d046ef0d9aede6ea9f1f72e895435e6ac651edf3fb", null ]
    ] ],
    [ "lms_testsig_t", "group___f_n___h_i_g_h___l_v_l.html#gaf9ea395b6b3cc7bdfb7179cfbf371302", [
      [ "LMS_TESTSIG_NONE", "group___f_n___h_i_g_h___l_v_l.html#ggaf9ea395b6b3cc7bdfb7179cfbf371302a84c8c25fb38420690e2bf6e3d7fa4678", null ],
      [ "LMS_TESTSIG_NCODIV8", "group___f_n___h_i_g_h___l_v_l.html#ggaf9ea395b6b3cc7bdfb7179cfbf371302a512f5eb1fb942907d1d2f9dd0cb57b95", null ],
      [ "LMS_TESTSIG_NCODIV4", "group___f_n___h_i_g_h___l_v_l.html#ggaf9ea395b6b3cc7bdfb7179cfbf371302a9cd4da11ebb85792a750280b78aeb2db", null ],
      [ "LMS_TESTSIG_NCODIV8F", "group___f_n___h_i_g_h___l_v_l.html#ggaf9ea395b6b3cc7bdfb7179cfbf371302af0b9272770073e56657f0e33d70eddf1", null ],
      [ "LMS_TESTSIG_NCODIV4F", "group___f_n___h_i_g_h___l_v_l.html#ggaf9ea395b6b3cc7bdfb7179cfbf371302ae0c1d4593864cdb15bc175e0a69feba6", null ],
      [ "LMS_TESTSIG_DC", "group___f_n___h_i_g_h___l_v_l.html#ggaf9ea395b6b3cc7bdfb7179cfbf371302a2103fbb9adec3c65000a7eb280ecae9e", null ]
    ] ],
    [ "LMS_Calibrate", "group___f_n___h_i_g_h___l_v_l.html#ga30253e6e7221c70d726b6bb06c69e43e", null ],
    [ "LMS_EnableChannel", "group___f_n___h_i_g_h___l_v_l.html#ga221f83ab83d4423b6b810551d261731f", null ],
    [ "LMS_GetAntenna", "group___f_n___h_i_g_h___l_v_l.html#ga77cf01129289aaa3df1b11ddb430d76e", null ],
    [ "LMS_GetAntennaBW", "group___f_n___h_i_g_h___l_v_l.html#gaf940f9c5448e32464453f0051f484e76", null ],
    [ "LMS_GetAntennaList", "group___f_n___h_i_g_h___l_v_l.html#ga7845dcd023f2ee17b38cec55eaff5d9f", null ],
    [ "LMS_GetChipTemperature", "group___f_n___h_i_g_h___l_v_l.html#gac1c5a04e011a57401b5f58806a5bf399", null ],
    [ "LMS_GetGaindB", "group___f_n___h_i_g_h___l_v_l.html#ga234cd6b4e32973d627ae369c353bbd56", null ],
    [ "LMS_GetLOFrequency", "group___f_n___h_i_g_h___l_v_l.html#ga0abde7a7cb9049f96c3d33de71eabd2a", null ],
    [ "LMS_GetLOFrequencyRange", "group___f_n___h_i_g_h___l_v_l.html#ga4fb02282949f45ec15baddc0c591c325", null ],
    [ "LMS_GetLPFBW", "group___f_n___h_i_g_h___l_v_l.html#ga07244b37a3f21bf20f626eddc9b3d399", null ],
    [ "LMS_GetLPFBWRange", "group___f_n___h_i_g_h___l_v_l.html#gaa1ef3ea17a29cb1b087d4bcfbf481169", null ],
    [ "LMS_GetNormalizedGain", "group___f_n___h_i_g_h___l_v_l.html#ga8f560ebdc5a13f2337926acbe13a4120", null ],
    [ "LMS_GetNumChannels", "group___f_n___h_i_g_h___l_v_l.html#gaff8fc19d9453348757cdb2fabb9f7cfd", null ],
    [ "LMS_GetSampleRate", "group___f_n___h_i_g_h___l_v_l.html#ga558a76ff122d71bfe6af57262ea8ed0f", null ],
    [ "LMS_GetSampleRateRange", "group___f_n___h_i_g_h___l_v_l.html#ga2be0ab821f7a13e137c807521bb0e467", null ],
    [ "LMS_GetTestSignal", "group___f_n___h_i_g_h___l_v_l.html#ga0555e1812314d548c15e6cbddcc06612", null ],
    [ "LMS_Init", "group___f_n___h_i_g_h___l_v_l.html#ga804769c6df1bb5c86829f6211c0c56aa", null ],
    [ "LMS_LoadConfig", "group___f_n___h_i_g_h___l_v_l.html#ga6ed2978c8a23248e27406725a293a3c3", null ],
    [ "LMS_SaveConfig", "group___f_n___h_i_g_h___l_v_l.html#ga2160d093e5c947adbaddafec1e041427", null ],
    [ "LMS_SetAntenna", "group___f_n___h_i_g_h___l_v_l.html#gace44b0474b90b6e1cc540ebef650b5d2", null ],
    [ "LMS_SetGaindB", "group___f_n___h_i_g_h___l_v_l.html#ga19d4810a0cf125cf82420f5c6bfcee6f", null ],
    [ "LMS_SetGFIRLPF", "group___f_n___h_i_g_h___l_v_l.html#gabf1f79d0561a8242ffe356d497f5f970", null ],
    [ "LMS_SetLOFrequency", "group___f_n___h_i_g_h___l_v_l.html#ga2c59e97985e0dfccf935c8bd78d5248d", null ],
    [ "LMS_SetLPF", "group___f_n___h_i_g_h___l_v_l.html#gab3696f37529eee3be9c57a37e8c05a4a", null ],
    [ "LMS_SetLPFBW", "group___f_n___h_i_g_h___l_v_l.html#gad7c91857ba6e83bf060e5359420925a7", null ],
    [ "LMS_SetNormalizedGain", "group___f_n___h_i_g_h___l_v_l.html#gad56e10da5335c7c8f74e31dd85d1e288", null ],
    [ "LMS_SetSampleRate", "group___f_n___h_i_g_h___l_v_l.html#ga545f1221449b14be75f3f7855af13dfa", null ],
    [ "LMS_SetTestSignal", "group___f_n___h_i_g_h___l_v_l.html#gac9e743da5a20e2b337238e94644b2c1a", null ],
    [ "LMS_CH_RX", "group___f_n___h_i_g_h___l_v_l.html#ga6315347ecc9dbff0d1ead974be3e8885", null ],
    [ "LMS_CH_TX", "group___f_n___h_i_g_h___l_v_l.html#ga8b66470dd0604888079174a9f9a96daa", null ]
];
